<?php

namespace App\Controller;

use App\Entity\PieceModele;
use App\Repository\PieceModeleRepository;
use DateTime;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/pieceModele')]
class PieceModeleController extends AbstractController
{
    #[Route('/', name: 'app_piece_modele')]
    public function index(PieceModeleRepository $pieceModeleRepository): Response
    {
        return $this->render('piece_modele/index.html.twig', [
            'piece_modeles' => $pieceModeleRepository->findAll(),
        ]);
    }

    #[Route('/{id}', name: 'app_piece_modele_show', requirements: ['id' => '\d+'])]
    public function show(int $id, PieceModeleRepository $pieceModeleRepository): Response
    {
        $pieceModele = $pieceModeleRepository->find($id);

        if (!$pieceModele) {
            throw $this->createNotFoundException('La pièce modèle avec l\'identifiant '.$id.' n\'existe pas.');
        }
        return $this->render('piece_modele/show.html.twig', [
            'piece_modele' => $pieceModele,
        ]);
    }

    #[Route('/insert', name: 'app_piece_modele_insert')]
    public function insert(EntityManagerInterface $entityManager): Response
    {
        $pieceModele = new PieceModele();

        $pieceModele->setPieceVersion("une Version");
        $pieceModele->setPieceValeur(1);
        $pieceModele->setPieceDateFrappee(new DateTime('2000-01-01'));
        $pieceModele->setPieceQuantiteFrappee("10");

        $entityManager->persist($pieceModele);
        $entityManager->flush();

        return $this->redirectToRoute('app_piece_modele_show',[
            'id' => $pieceModele->getId(),
        ], Response::HTTP_SEE_OTHER);
    }

    #[Route('/update/{id}', name: 'app_piece_modele_update')]
    public function update(PieceModele $pieceModele, EntityManagerInterface $entityManager): Response
    {
        $pieceModele->setPieceVersion("une Version differente");
        $pieceModele->setPieceValeur(2);
        $pieceModele->setPieceDateFrappee(new DateTime('2001-01-01'));
        $pieceModele->setPieceQuantiteFrappee("20");

        $entityManager->persist($pieceModele);
        $entityManager->flush();

        return $this->render('piece_modele/show.html.twig', [
            'piece_modele' => $pieceModele,
        ]);
    }

    #[Route('/delete/{id}', name: 'app_piece_modele_delete')]
    public function delete(PieceModele $pieceModele, EntityManagerInterface $entityManager): Response
    {
        $entityManager->remove($pieceModele);
        $entityManager->flush();

        return $this->redirectToRoute('app_piece_modele', [], Response::HTTP_SEE_OTHER);
    }
}
