<?php

namespace App\Controller;

use App\Entity\PieceTranche;
use App\Entity\PieceModele;
use App\Repository\PieceTrancheRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/pieceTranche')]
class PieceTrancheController extends AbstractController
{
    #[Route('/', name: 'app_piece_tranche')]
    public function index(PieceTrancheRepository $pieceTrancheRepository): Response
    {
        return $this->render('piece_tranche/index.html.twig', [
            'piece_tranches' => $pieceTrancheRepository->findAll(),
        ]);
    }

    #[Route('/{id}', name: 'app_piece_tranche_show', requirements: ['id' => '\d+'])]
    public function show(int $id ,PieceTrancheRepository $pieceTrancheRepository): Response
    {
        $pieceTranche = $pieceTrancheRepository->find($id);

        if (!$pieceTranche){
            throw $this->createNotFoundException('La tranche de la pièce avec l\'identifiant '.$id.' n\'existe pas.');
        }
        return $this->render('piece_tranche/show.html.twig', [
            'piece_tranche' => $pieceTranche,
        ]);
    }

    #[Route('/insert', name: 'app_piece_tranche_insert')]
    public function insert(EntityManagerInterface $entityManager): Response
    {
        $pieceModele = $entityManager->getRepository(PieceModele::class)->find(1);

        $pieceTranche = new PieceTranche();

        $pieceTranche->setPieceModeleID($pieceModele);
        $pieceTranche->setPieceTranche("Une Tranche");

        $entityManager->persist($pieceTranche);
        $entityManager->flush();

        return $this->redirectToRoute('app_piece_tranche_show',[
            'id' => $pieceTranche->getId(),
        ], Response::HTTP_SEE_OTHER);
    }

    #[Route('/update/{id}', name: 'app_piece_tranche_update')]
    public function edit(PieceTranche $pieceTranche, EntityManagerInterface $entityManager): Response
    {
        $pieceTranche->setPieceTranche("une Tranche differente");
        $pieceModele = $entityManager->getRepository(PieceModele::class)->find(2);
        $pieceTranche->setPieceModeleID($pieceModele);

        $entityManager->persist($pieceTranche);
        $entityManager->flush();

        return $this->render('piece_tranche/show.html.twig', [
            'piece_tranche' => $pieceTranche,
        ]);
    }

    #[Route('/delete/{id}', name: 'app_piece_tranche_delete')]
    public function delete(PieceTranche $pieceTranche, EntityManagerInterface $entityManager): Response
    {
        $entityManager->remove($pieceTranche);
        $entityManager->flush();

        return $this->redirectToRoute('app_piece_tranche', [], Response::HTTP_SEE_OTHER);
    }
}
